<p align=center>

     it is the DEMO Package created for educational purpose 
          Lord Shiva praises to me

                THANK YOU
<br>

<a target="_blank" href="https://www.python.org/downloads/" title="Python version"><img src="https://img.shields.io/badge/python-%3E=_3.6-green.svg"></a>
<a target="_blank"
href="https://github.com/nethra-coding/Lord_Shiva.git"
title="GITHUB"><img src="https://img.shields.io/badge/github-github-orange"></a>
<a target="_blank" href="https://twitter.com/intent/tweet?&url=https://github.com/nethra-coding/lord-shiva.git&hashtags= module ,%20python" title="share on twitter"><img src="https://img.shields.io/twitter/url/http/shields.io.svg?style=social"></a>
</p>

<br>

<p align="center">
  <a href="#details">Details</a>
  &nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
  <a href="#module">MODULE</a>
  &nbsp;&nbsp;&nbsp;|&nbsp;&nbsp;&nbsp;
</p>

##Details:

     Author :
                NETHRAN KUMARASAMY
<br>

     EMAIL  :

                ramanathank18@gmail.com
<br>

##MODULE

           lord-shiva


